@@ -2,7 +2,7 @@ require 'spec_helper'
 
 describe 'neutron::plugins::plumgrid' do
   let :pre_condition do
-    "class { '::neutron::keystone::authtoken':
+    "class { 'neutron::keystone::authtoken':
       password => 'passw0rd',
      }
      class { 'neutron::server': }
@@ -14,7 +14,7 @@ describe 'neutron::plugins::plumgrid' do
     :director_server      => '127.0.0.1',
     :director_server_port => '443',
     :servertimeout        => '99',
-    :connection           => 'http://127.0.0.1:5000/v2.0',
+    :connection           => 'http://127.0.0.1:5000/v3',
     :controller_priv_host => '127.0.0.1',
     :auth_protocol        => 'http',
     :identity_version     => 'v3',
@@ -76,6 +76,7 @@ describe 'neutron::plugins::plumgrid' do
     it 'should perform default configuration of plumgrid plumlib' do
       auth_uri = params[:auth_protocol] + "://" + params[:controller_priv_host] + ":" + "5000/" + params[:identity_version];
       should contain_neutron_plumlib_plumgrid('keystone_authtoken/auth_uri').with_value(auth_uri)
+      should contain_neutron_plumlib_plumgrid('keystone_authtoken/www_authenticate_uri').with_value(auth_uri)
       should contain_neutron_plumlib_plumgrid('keystone_authtoken/identity_version').with_value(params[:identity_version])
       should contain_neutron_plumlib_plumgrid('keystone_authtoken/user_domain_name').with_value(params[:user_domain_name])
       should contain_neutron_plumlib_plumgrid('PLUMgridMetadata/enable_pg_metadata').with_value('True')
